@@ -71,6 +71,8 @@ class AbstractSolarluxUser(AbstractBaseUser, PermissionsMixin):
     password = models.CharField(_("password"), max_length=128, null=True, blank=True)
 
     sap_pernr = models.IntegerField(_("SAP Pernr"), null=True, blank=True)
+    sap_sales_org = models.CharField(_('SAP Verkaufsorganisation'), max_length=4, null=True, blank=True)
+    sap_company_code = models.CharField(_('SAP Buchungskreis'), max_length=4, null=True, blank=True)
     country_code = models.CharField(_('Länderkürzel'), max_length=2, null=True, blank=True)
     mobile_number = models.CharField(_('Mobilnummer'), max_length=255, null=True, blank=True)
     department = models.CharField(_('Abteilung'), max_length=50, null=True, blank=True)
