@@ -86,10 +86,10 @@ class TokenAuthenticator:
         user.crm_contact_id = token_data["crmContactId"]
         user.email = token_data["email"]
         user.sap_pernr = token_data["sapPernr"] if "sapPernr" in token_data else None
+        user.sap_sales_org = token_data["sapSalesOrg"] if "sapSalesOrg" in token_data else None
+        user.sap_company_code = token_data["sapCompanyCode"] if "sapCompanyCode" in token_data else None
         user.country_code = token_data["countryCode"] if "countryCode" in token_data else None
-        # Auskommentiert da vorerst der wert nicht aus dem Usermanagement übernommen werden soll
-        # sondern manuell in der app gesetzt wird
-        # user.department = token_data["department"] if "department" in token_data else None
+        user.department = token_data["department"] if "department" in token_data else None
         user.mobile_number = token_data["mobileNumber"] if "mobileNumber" in token_data else None
 
         user_groups = user.groups.all()
